@@ -6,7 +6,7 @@ import pyctcdecode
 def transcription(audio_path):
 
 	# my_model_id = "loulely/XLSR_300M_Fine_Tuning_FR_2"
-	my_model_id = "./"
+	my_model_id = "./my_model"
 
 	# load model and processor
 	my_model = AutoModelForCTC.from_pretrained(my_model_id)
